@@ -20,11 +20,10 @@ from scipy import integrate
 # logging
 log = simplelogging.get_logger()
 
+
 # load the tdms file
 
 
-
-
 def create_arg_parser():
     """"Creates and returns the ArgumentParser object."""
 
@@ -34,6 +33,7 @@ def create_arg_parser():
     parser.add_argument("--data", type=str, help="Path to the data directory.")
     return parser
 
+
 def get_output(path):
     ABS_PATH = os.path.abspath(path)
     CSV_PATH = os.path.join(ABS_PATH, "CSV DATA")
@@ -59,6 +59,7 @@ def output_directories(path):
 def vivdict():
     return defaultdict(vivdict)
 
+
 def load_data(path):
     # Handles nested dictionaries for us
     CSV_PATH, PLOT_PATH, RAW_CSV_DATA = output_directories(path)
@@ -120,6 +121,8 @@ def write_and_plot(sample_dict, path):
     composite_data = vivdict()
     integral_data = []
     std_data = {}
+    VOLUME = 1.2
+    VOLUME_CALCULATED = (VOLUME / (60 * 1000))
 
     for family in sample_families:
         for method, _ in sample_dict[family].items():
@@ -129,8 +132,13 @@ def write_and_plot(sample_dict, path):
 
             # Integral
             heating = cd[0:150]
+            ppm = heating.mul(10000*1.9378)
+            ppm.reset_index(inplace=True)
+            ppm['Volume'] = ppm['Time'].apply(lambda x: x * VOLUME_CALCULATED)
+            ppm.set_index('Volume', inplace=True)
+            ppm = ppm.drop(columns=['Time'], errors='ignore', level=0)
             row_integral = (
-                heating.ewm(span=5).mean().apply(lambda g: integrate.trapz(g))
+                ppm.ewm(span=5).mean().apply(lambda g: integrate.trapz(x=g.index, y=g.values))
             )
             row_integral_std = row_integral.std()
             integral = pd.DataFrame(
@@ -197,6 +205,7 @@ def write_and_plot(sample_dict, path):
         toolbar_location=None,
         title="CO2 Integral",
         background_fill_color="#efefef",
+        y_axis_label='CO2 (mg)'
     )
     p.circle(
         x="index", y="Integral", color="red", fill_alpha=0.2, size=10, source=source
@@ -209,7 +218,6 @@ def write_and_plot(sample_dict, path):
     p.xaxis.major_label_orientation = "vertical"
     p.y_range.start = integral_df["Integral"].min() - integral_df["STD"].max() - 5
     p.y_range.end = integral_df["Integral"].max() + integral_df["STD"].max() + 5
-
     hover = HoverTool()
     hover.tooltips = [("Sample", "@index"), ("Value", "@Integral"), ("STD", "@STD")]
 
@@ -225,10 +233,10 @@ if __name__ == "__main__":
     if parsed_args:
         if os.path.exists(parsed_args.data):
             try:
-                raw_dta  = load_data(parsed_args.data)
+                raw_dta = load_data(parsed_args.data)
                 write_and_plot(sample_dict=raw_dta, path=parsed_args.data)
             except TypeError as e:
                 log.debug(f"{e}")
-                raise(e)
+                raise (e)
     else:
         log.debug(f"Doesn't look like you entered a proper directory: {parsed_args}")
